searchData={"items":[{"type":"module","title":"Debouncer","doc":"Debouncer executes a function call debounced. Debouncing is done one a per key basis:\n\n```\nDebouncer.apply(Key, fn() -> IO.puts(\"Hello World, debounced\") end)\n```\n\nThe third optional parameter is the timeout period in milliseconds\n\n```\nDebouncer.apply(Key, fn() -> IO.puts(\"Hello World, once per minute max\") end, 60_000)\n```\n\nThe variants supported are:\n\n* `apply/3`      => Events are executed after the timeout\n* `immediate/3`  => Events are executed immediately, and further events are delayed for the timeout\n* `immediate2/3` => Events are executed immediately, and further events are IGNORED for the timeout\n* `delay/3`      => Each event delays the execution of the next event\n\n```\nEVENT        X1---X2------X3-------X4----------\nTIMEOUT      ----------|----------|----------|-\n===============================================\napply()      ----------X2---------X3---------X4\nimmediate()  X1--------X2---------X3---------X4\nimmediate2() X1-----------X3-------------------\ndelay()      --------------------------------X4\n```","ref":"Debouncer.html"},{"type":"function","title":"Debouncer.apply/3","doc":"Executes the function after the specified timeout t0 + timeout,\nwhen apply is called multiple times it does not affect the point\nin time when the next call is happening (t0 + timeout) but updates the fun","ref":"Debouncer.html#apply/3"},{"type":"function","title":"Debouncer.cancel/1","doc":"Deletes the latest event if it hasn't triggered yet.","ref":"Debouncer.html#cancel/1"},{"type":"function","title":"Debouncer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Debouncer.html#child_spec/1"},{"type":"function","title":"Debouncer.delay/3","doc":"Executes the function after the specified timeout t0 + timeout,\nwhen delay is called multipe times the timeout is reset based on the\nmost recent call (t1 + timeout, t2 + timeout) etc... the fun is also updated","ref":"Debouncer.html#delay/3"},{"type":"function","title":"Debouncer.immediate2/3","doc":"Executes the function immediately but ignores further calls\nunder the same key for the given timeout.","ref":"Debouncer.html#immediate2/3"},{"type":"function","title":"Debouncer.immediate/3","doc":"Executes the function immediately but blocks any further call\nunder the same key for the given timeout.","ref":"Debouncer.html#immediate/3"},{"type":"function","title":"Debouncer.worker/1","doc":"Returns the pid of an active job worker or nil if no such job is scheduled.\nPer key the debouncer never starts more than one process at the same time.","ref":"Debouncer.html#worker/1"},{"type":"extras","title":"Debouncer","doc":"# Debouncer ![Build](https://github.com/dominicletz/debouncer/actions/workflows/test.yml/badge.svg)\n\nDebouncer module to reduce frequency of function calls to alerts, updates and similar. It supports four different modes:\n\n* `apply()`      - For delayed triggers, e.g. to trigger an __autocomplete__ action\n* `immediate()`  - For reducing frequency of events, the first event per interval is delivered immediately, e.g. trigger __data processing tasks__ \n* `immediate2()` - Similiar to immediate but never delays events, either forwards them or ignores them, e.g. to trigger __alert emails__ \n* `delay()`      - Only triggers an event after the timeout period, any further event delays the trigger. E.g. to detect data streams that __ended actvitiy__","ref":"readme.html"},{"type":"extras","title":"Usage Example - Debouncer","doc":"```elixir\n  Debouncer.apply(SomeKey, fn() -> \n    IO.puts(\"Hello World, debounced will appear in 5 seconds\") \n  end)\n```\n\n```elixir\n  Debouncer.immediate(OtherKey, fn() -> \n    IO.puts(\"Hello World, will appear immediate, but not again within 5 seconds\") \n  end)\n```","ref":"readme.html#usage-example"},{"type":"extras","title":"Behaviour Graph - Debouncer","doc":"```\nEVENT        X1---X2------X3-------X4----------\nTIMEOUT      ----------|----------|----------|-\n===============================================\napply()      ----------X2---------X3---------X4\nimmediate()  X1--------X2---------X3---------X4\nimmediate2() X1-----------X3-------------------\ndelay()      --------------------------------X4\n```\n\nThis graph represents when the different variants fire an event respectively on a timeline. In code the first line would look like this:\n\n```elixir\nfn ->\n  Debouncer.apply(SomeKey, fn() -> IO.puts(\"X1\") end, 1000)\n  Process.sleep(500)\n  Debouncer.apply(SomeKey, fn() -> IO.puts(\"X2\") end, 1000)\n  Process.sleep(800)\n  Debouncer.apply(SomeKey, fn() -> IO.puts(\"X3\") end, 1000)\n  Process.sleep(900)\n  Debouncer.apply(SomeKey, fn() -> IO.puts(\"X4\") end, 1000)\n  Process.sleep(1200)\nend.()\n\n> X2\n> X3\n> X4\n```","ref":"readme.html#behaviour-graph"},{"type":"extras","title":"Shorthands - Debouncer","doc":"When using Module-Function-Argument tuples as callbacks (aka `mfa`) it can be convenient to skip the key and use the mfa itself as key:\n\n```elixir\n# Call later() function immediately with the default 5 second debounce:\nDebouncer.immediate({__MODULE__, :later, []})\n\n# Call later() function immediately with 1 second debounce:\nDebouncer.immediate({__MODULE__, :later, []}, 1_000)\n\n# Same but in using method binding\nDebouncer.immediate(&later/0, 1_000)\n```\n\n**WARNING**\n\nDon't use in-place fun definitions in the shorthand, as those not work as unique-key because each call will be a different instance. So the debounce counting won't work.\n\nExample:\n\n```elixir\n# Because (`fn -> 1 end != fn -> 1 end`) don't do this:\nDebouncer.immediate(fn -> later() end, 1_000)\n```","ref":"readme.html#shorthands"},{"type":"extras","title":"Installation - Debouncer","doc":"The debouncer can be installed by adding `debouncer` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:debouncer, \"~> 0.1\"}\n  ]\nend\n```\n\nThe debouncer is an application and will start a GenServer to trigger the events. To include the Application in your release add it to your extra applications:\n\n```elixir\n  def application do\n    [\n      mod: {Your.Application, []},\n      extra_applications: [:debouncer]\n    ]\n  end\n\n```\n\nIf it's not started it will try to start itself on usage.\n\nThe docs can be found at [https://hexdocs.pm/debouncer](https://hexdocs.pm/debouncer).","ref":"readme.html#installation"},{"type":"extras","title":"Remarks - Debouncer","doc":"The `delay()` behaviour should be the same as in Michal Muskalas Debounce implementation https://github.com/michalmuskala/debounce","ref":"readme.html#remarks"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}